---
layout: default
title: Home
notitle: true
---

{% include hero.html %}

## Overview

XGrammar is open-source solution for flexible, portable, and fast structured generations,
aiming at bring flexible zero-overhead structure generation everywhere.
It supports general context-free grammar to enable a broad range of structures while bringing careful system optimizations to enable fast executions.
XGrammar features a minimal and portable C++ backend that can be easily integrated into multiple environments and frameworks,
and is co-designed with the LLM inference engine and enables zero-overhead structured generation in LLM inference.

## Get Started

Please visit our [documentation](https://xgrammar.mlc.ai/docs/) to get started with XGrammar.
- [Installation](https://xgrammar.mlc.ai/docs/start/install)
- [Quick start](https://xgrammar.mlc.ai/docs/start/quick_start)

## Links
- [XGrammar Github](https://github.com/mlc-ai/xgrammar)
